# Security Policy

SSB takes the security of our software products and services seriously, which
includes all source code repositories managed through our GitHub organization.

We believe that responsible disclosure of security vulnerabilities helps us ensure
the security and privacy of all our users.

## Reporting a Vulnerability

If you believe you have found a security vulnerability in any of SSB's GitHub
repositories, please report it to us using the
[Github Private vulnerability reporting tool](https://github.com/statisticsnorway/dapla-toolbelt-metadata/security/advisories).
